Example 3: Collective self consumption
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
The shape of an energy project depends on the available technologies but also on
stakeholdersâ€™ decisions although most energy-support-decision tools only focus on
technical issues.

We aim to propose a multi-actor modelling based on actorsâ€™ objectives and constraints
and to apply it on the model generation tool for optimization OMEGAlpes. This modelling
aims to help stakeholders to formalize their constraints and objectives and to negotiate
them in a multi-actor design process.
This modelling has been applied to a simplified collective self-consumption project.

| The code is available here: `BS2019 multi-actor Modelling code`_
| The article presenting this example is available at: `BS2019 multi-actor Modelling article`_
| You can access to this example via an online Notebook at: `BS2019 multi-actor Modelling notebook`_

.. figure::  images/2019BS_Multi-actor_modelling.PNG
   :align:   center
   :scale:   55%

   *Figure 2: Representation of the collective self-consumption project | Lou Morriet*